/////////////////////////////////////////////////////////////////////
// Code/main.h
//
// Copyright (c) Elements Interactive B.V.
// http://www.edgelib.com
//
// Contains the main wrapper class
/////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////
// Class definition                                                //
/////////////////////////////////////////////////////////////////////

//The main class
class ClassMain : public ClassEdge
{
	public:
		ClassMain(const EDGEDATA *data);
		~ClassMain(void);

		POINT Temp;

		ERESULT OnCreate(EDGECONFIG *config, EDGEDATA *data);
		ERESULT OnInit(EINSTANCE instance);
		ERESULT OnMinimize(void);
		ERESULT OnRestore(void);
		ERESULT OnDisplayInit(EINSTANCE instance, ClassEDisplay *display);
		ERESULT OnNextFrame(ClassEDisplay *display, unsigned long timedelta);
		void OnExit(EINSTANCE instance);
		void OnButtonDown(unsigned long bnr, EBUTTONLIST *blist);
		void OnButtonUp(unsigned long bnr, EBUTTONLIST *blist);
		void OnWheel(long direction);
		void OnStylusUp(POINT pnt);
		void OnStylusDown(POINT pnt);
		void OnStylusDouble(POINT pnt);
		void OnStylusMove(POINT pnt);
		void OnNetMessage(unsigned char connection, long id, long msg, long bufsize, unsigned char *buffer);
};


/////////////////////////////////////////////////////////////////////
// ClassMain: public                                               //
/////////////////////////////////////////////////////////////////////

//ClassMain: constructor
ClassMain::ClassMain(const EDGEDATA *data) : ClassEdge(data)
{
}

//ClassMain: destructor
ClassMain::~ClassMain(void)
{
}

//Callback: Called immediatly after starting the program, configure Edge here
ERESULT ClassMain::OnCreate(EDGECONFIG *config, EDGEDATA *data)
{
	config->ffwdkey         = 'A';                //A key for fast forwarding (multiplies framerate by 2.5)
	config->slomokey        = 'S';                //A key for slow motion     (halves framerate)
	config->maxfps          = 60;                 //Limit the maximum frames per second by 60
	config->flags           = 0;                  //No extra flag options
	config->videowidth      = 240;                //Desktop PC: Custom display width
	config->videoheight     = 320;                //Desktop PC: Custom display height
	config->videotype       = EDSP_DEFAULT;       //Choose the default display mode
	config->emulvideotype   = EDSP_DEFAULT;       //No color depth emulation
	config->rotation        = ROT_NONE;           //Display orientation
	config->numconnections  = 1;                  //Keep 1 active network connection
	config->resolution      = ERS_REQUIREHIGHRES; //Try to emulate low-resolution on high-resolution devices by hardware
	#if defined(DEVICE_GP2X)
		config->smartfps    = false;              //GP2X: No smartfps needed
	#else
		config->smartfps    = true;               //Other devices: Enable smart fps lock managing
	#endif
	#if defined(DEVICE_DESKTOP)
		config->focusminimize = false;            //Desktop PC: Don't minimize the application when the focus is lost
	#else
		config->focusminimize = true;             //Mobile devices: Minimize the application when the focus is lost
	#endif
	config->enginestatus    = true;               //Desktop PC: Enable the status bar and status information icon
	config->engineconsole   = false;              //Desktop PC: Disable the edge console
	config->fullscreen      = false;              //Desktop PC: A windowed application
	config->fullscreenmouse = true;               //Desktop PC: Enable the mouse cursor for fullscreen applications
	config->jogtiltarrow    = true;               //Emulate the UIQ jog as left/right arrows
	config->focussuspend    = true;               //Desktop PC: suspend the application when the window focus is lost
	return(E_OK);
}

//Callback: Called before the display mode changes
ERESULT ClassMain::OnInit(EINSTANCE instance)
{
	return(E_OK);
}

//Callback: Called when the program minimizes
ERESULT ClassMain::OnMinimize(void)
{
	return(E_OK);
}

//Callback: Called when the program restores back from a minimized state
ERESULT ClassMain::OnRestore(void)
{
	return(E_OK);
}

//Callback: Called when the display mode has changed, use this to initialize your surfaces, etc.
ERESULT ClassMain::OnDisplayInit(EINSTANCE instance, ClassEDisplay *display)
{
	return(E_OK);
}

//Callback: Called every frame
ERESULT ClassMain::OnNextFrame(ClassEDisplay *display, unsigned long timedelta)
{
	display->buffer.FillRect (NULL, 0);
	display->buffer.DrawFont(2, 20, &display->fontinternal, Temp.x);
	display->buffer.DrawFont(30, 20, &display->fontinternal, Temp.y);
	

	display->buffer.DrawFont(0, 0, &display->fontinternal, "*");
	display->buffer.DrawFont(470, 0, &display->fontinternal, "#");
	display->buffer.DrawFont(0, 630, &display->fontinternal, "+");
	display->buffer.DrawFont(470, 630, &display->fontinternal, "&");

	return(E_OK);
}

//Callback: Called when the program exits
void ClassMain::OnExit(EINSTANCE instance)
{
}

//Callback: Called when the user pressed a key or button
void ClassMain::OnButtonDown(unsigned long bnr, EBUTTONLIST *blist)
{
	Quit();
}

//Callback: Called when the user released a key or button
void ClassMain::OnButtonUp(unsigned long bnr, EBUTTONLIST *blist)
{
}

//Callback: Called when the user scrolls a wheel device
void ClassMain::OnWheel(long direction)
{
}

//Callback: Called when the user released the stylus or mouse button
void ClassMain::OnStylusUp(POINT pnt)
{
	Temp = pnt;
}

//Callback: Called when the user points the stylus down or clicks the left mouse button
void ClassMain::OnStylusDown(POINT pnt)
{
	Temp = pnt;
}

//Callback: Called when the user points the stylus 2 times down quickly or double clicks the left mouse button
void ClassMain::OnStylusDouble(POINT pnt)
{
}

//Callback: Called when the user moves the stylus while pressed down, or moves the mouse cursor
void ClassMain::OnStylusMove(POINT pnt)
{
	Temp = pnt;
}

//Callback: Called when a network event occurs
void ClassMain::OnNetMessage(unsigned char connection, long id, long msg, long bufsize, unsigned char *buffer)
{
}
